@@ -20,6 +20,21 @@ __all__ = ["to_dict", "from_dict", "save", "load"]
 SERIALIZABLE_REGISTRY = {}
 
 
+def shorten_class_name(class_fullname):
+    splitted = class_fullname.split(".")
+    if len(splitted) == 1:
+        return class_fullname
+    top_module, *_, class_name = splitted
+    if top_module == "albumentations":
+        return class_name
+    return class_fullname
+
+
+def get_shortest_class_fullname(cls):
+    class_fullname = "{cls.__module__}.{cls.__name__}".format(cls=cls)
+    return shorten_class_name(class_fullname)
+
+
 class SerializableMeta(type):
     """
     A metaclass that is used to register classes in `SERIALIZABLE_REGISTRY` so they can be found later
@@ -95,7 +110,7 @@ def from_dict(transform_dict, lambda_transforms=None):
         return lmbd
     name = transform["__class_fullname__"]
     args = {k: v for k, v in transform.items() if k != "__class_fullname__"}
-    cls = SERIALIZABLE_REGISTRY[name]
+    cls = SERIALIZABLE_REGISTRY[shorten_class_name(name)]
     if "transforms" in args:
         args["transforms"] = [
             from_dict({"transform": t}, lambda_transforms=lambda_transforms) for t in args["transforms"]
